aboutsummaryrefslogtreecommitdiffstats
path: root/gcc-4.9/libgfortran/generated/pack_c8.c
diff options
context:
space:
mode:
Diffstat (limited to 'gcc-4.9/libgfortran/generated/pack_c8.c')
-rw-r--r--gcc-4.9/libgfortran/generated/pack_c8.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/gcc-4.9/libgfortran/generated/pack_c8.c b/gcc-4.9/libgfortran/generated/pack_c8.c
index f291b4676..38880c183 100644
--- a/gcc-4.9/libgfortran/generated/pack_c8.c
+++ b/gcc-4.9/libgfortran/generated/pack_c8.c
@@ -167,8 +167,8 @@ pack_c8 (gfc_array_c8 *ret, const gfc_array_c8 *array,
ret->offset = 0;
- /* xmalloc allocates a single byte for zero size. */
- ret->base_addr = xmalloc (sizeof (GFC_COMPLEX_8) * total);
+ /* xmallocarray allocates a single byte for zero size. */
+ ret->base_addr = xmallocarray (total, sizeof (GFC_COMPLEX_8));
if (total == 0)
return;